import { NonNullablePaths } from '@wix/sdk-types';
export interface Role {
    roleKey?: string;
    title?: string;
}
export interface AssignRoleRequest {
    /** @format GUID */
    memberId: string;
    roleKey: string;
}
export interface AssignRoleResponse {
    roleKey?: string;
}
export interface UnassignRoleRequest {
    /** @format GUID */
    memberId: string;
    roleKey: string;
}
export interface UnassignRoleResponse {
    roleKey?: string;
}
export interface GetRolesRequest {
    /** @format GUID */
    memberId: string;
}
export interface GetRolesResponse {
    roles?: Role[];
}
export interface QueryRolesRequest {
    /** Query options. */
    query?: Query;
}
export interface Query {
    /** A filter object. See documentation [here](https://bo.wix.com/wix-docs/rnd/platformization-guidelines/api-query-language#platformization-guidelines_api-query-language_defining-in-protobuf) */
    filter?: any;
}
export interface QueryRolesResponse {
    /** Map of members that met the query filter criteria. */
    rolesByMemberId?: Record<string, MemberRole>;
}
export interface MemberRole {
    roles?: Role[];
}
export interface PolicyAssignedToContributor {
    /** @format GUID */
    accountId?: string;
    /** @format GUID */
    metaSiteId?: string;
    policyIds?: string[];
}
export interface Empty {
}
export interface PolicyRemovedFromContributor {
    /** @format GUID */
    accountId?: string;
    /** @format GUID */
    metaSiteId?: string;
    policyIds?: string[];
}
export interface PolicyUpdatedForContributor {
    /** @format GUID */
    accountId?: string;
    /** @format GUID */
    metaSiteId?: string;
    oldPolicyIds?: string[];
    newPolicyIds?: string[];
}
type RoleNonNullablePaths = `roleKey` | `title`;
/** @public
 * @documentationMaturity preview
 * @requiredField memberId
 * @requiredField roleKey
 * @permissionId MEMBERS.MEMBER_ROLES_MANAGE
 * @applicableIdentity MEMBER
 * @fqn com.wixpress.members.memberroles.MemberRoles.AssignRole
 */
export declare function assignRole(memberId: string, roleKey: string): Promise<NonNullablePaths<AssignRoleResponse, `roleKey`>>;
/** @public
 * @documentationMaturity preview
 * @requiredField memberId
 * @requiredField roleKey
 * @permissionId MEMBERS.MEMBER_ROLES_MANAGE
 * @applicableIdentity MEMBER
 * @fqn com.wixpress.members.memberroles.MemberRoles.UnassignRole
 */
export declare function unassignRole(memberId: string, roleKey: string): Promise<NonNullablePaths<UnassignRoleResponse, `roleKey`>>;
/** @public
 * @documentationMaturity preview
 * @requiredField memberId
 * @permissionId MEMBERS.ROLES_READ
 * @applicableIdentity VISITOR
 * @fqn com.wixpress.members.memberroles.MemberRoles.GetRoles
 */
export declare function getRoles(memberId: string): Promise<NonNullablePaths<GetRolesResponse, {
    [P in RoleNonNullablePaths]: `roles.${number}.${P}`;
}[RoleNonNullablePaths]>>;
/** @public
 * @documentationMaturity preview
 * @permissionId MEMBERS.ROLES_READ
 * @applicableIdentity VISITOR
 * @fqn com.wixpress.members.memberroles.MemberRoles.QueryRoles
 */
export declare function queryRoles(options?: QueryRolesOptions): Promise<QueryRolesResponse>;
export interface QueryRolesOptions {
    /** Query options. */
    query?: Query;
}
export {};
