import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixMembersV1Role from './members-v1-role-authorization.http.js';
/** @public
 * @documentationMaturity preview
 * @requiredField memberId
 * @requiredField roleKey
 * @permissionId MEMBERS.MEMBER_ROLES_MANAGE
 * @applicableIdentity MEMBER
 * @fqn com.wixpress.members.memberroles.MemberRoles.AssignRole
 */
export async function assignRole(memberId, roleKey) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        memberId: memberId,
        roleKey: roleKey,
    });
    const reqOpts = ambassadorWixMembersV1Role.assignRole(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]', roleKey: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['memberId', 'roleKey']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/** @public
 * @documentationMaturity preview
 * @requiredField memberId
 * @requiredField roleKey
 * @permissionId MEMBERS.MEMBER_ROLES_MANAGE
 * @applicableIdentity MEMBER
 * @fqn com.wixpress.members.memberroles.MemberRoles.UnassignRole
 */
export async function unassignRole(memberId, roleKey) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        memberId: memberId,
        roleKey: roleKey,
    });
    const reqOpts = ambassadorWixMembersV1Role.unassignRole(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]', roleKey: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['memberId', 'roleKey']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/** @public
 * @documentationMaturity preview
 * @requiredField memberId
 * @permissionId MEMBERS.ROLES_READ
 * @applicableIdentity VISITOR
 * @fqn com.wixpress.members.memberroles.MemberRoles.GetRoles
 */
export async function getRoles(memberId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ memberId: memberId });
    const reqOpts = ambassadorWixMembersV1Role.getRoles(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['memberId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/** @public
 * @documentationMaturity preview
 * @permissionId MEMBERS.ROLES_READ
 * @applicableIdentity VISITOR
 * @fqn com.wixpress.members.memberroles.MemberRoles.QueryRoles
 */
export async function queryRoles(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        query: options?.query,
    });
    const reqOpts = ambassadorWixMembersV1Role.queryRoles(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { query: '$[0].query' },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=members-v1-role-authorization.universal.js.map